Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(557)

Unified Diff: components/policy/core/common/schema_registry.h

Issue 2481233004: Rename SchemaRegistry::SetReady to SetDomainReady (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/policy/schema_registry_service.cc ('k') | components/policy/core/common/schema_registry.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/policy/core/common/schema_registry.h
diff --git a/components/policy/core/common/schema_registry.h b/components/policy/core/common/schema_registry.h
index 729b99a1b93738fb2173a06d19fbc479a564609a..ce787e769c56addef904297a34288b524b9413ab 100644
--- a/components/policy/core/common/schema_registry.h
+++ b/components/policy/core/common/schema_registry.h
@@ -74,11 +74,12 @@ class POLICY_EXPORT SchemaRegistry : public base::NonThreadSafe {
// This indicates that the initial components for |domain| have all been
// registered. It must be invoked at least once for each policy domain;
// subsequent calls for the same domain are ignored.
- void SetReady(PolicyDomain domain);
- // This is equivalent to calling |SetReady| with each of the policy domains.
+ void SetDomainReady(PolicyDomain domain);
+ // This is equivalent to calling |SetDomainReady| with each of the policy
+ // domains.
void SetAllDomainsReady();
// This is equivalent to calling |SetReady| with each of the domains that
// correspond to policy for extensions.
void SetExtensionsDomainsReady();
void AddObserver(Observer* observer);
« no previous file with comments | « chrome/browser/policy/schema_registry_service.cc ('k') | components/policy/core/common/schema_registry.cc » ('j') | no next file with comments »
@@ -74,11 +74,12 @@ class POLICY_EXPORT SchemaRegistry : public base::NonThreadSafe {
void SetAllDomainsReady();
- // This is equivalent to calling |SetReady| with each of the domains that
- // correspond to policy for extensions.
+ // This is equivalent to calling |SetDomainReady| with each of the domains
+ // that correspond to policy for extensions.
void SetExtensionsDomainsReady();
void AddObserver(Observer* observer);

Powered by Google App Engine
This is Rietveld 408576698